@@ -16,7 +16,7 @@ use Type::Library
      ExceptionType UserAgent HTTPResponse
   );
 
-our $VERSION = '0.923'; # VERSION
+our $VERSION = '0.924'; # VERSION
 
 enum ExceptionType, [qw.
     invalid_data
@@ -58,7 +58,7 @@ coerce Country,
 
 declare Money,
   as Str,
-  where { m|^ [\d\,]+ \. \d{2} $|x };
+  where { m|^ \-? [\d\,]+ \. \d{2} $|x };
 
 coerce Money,
   from Str,
@@ -103,7 +103,7 @@ Business::CPI::Util::Types - Basic types for Business::CPI
 
 =head1 VERSION
 
-version 0.923
+version 0.924
 
 =head1 DESCRIPTION
 
